@@ -14,7 +14,6 @@ module Sus
 			def initialize(state = :free, context = nil)
 				@state = state
 				@context = context
-				@index = 0
 			end
 			
 			INDICATORS = {
@@ -36,8 +35,6 @@ module Sus
 			end
 			
 			def print(output)
-				message = @message
-				
 				output.write(
 					@state, self.indicator, " "
 				)
